@@ -6,6 +6,8 @@ from .add import add
 from .any import any
 from .all import all
 from .allclose import allclose
+from .apply_along_axis import apply_along_axis
+from .apply_over_axes import apply_over_axes
 from .around import around as round, around
 from .array_repr import array_repr
 from .array_split import array_split
@@ -24,6 +26,7 @@ from .divide import divide
 from .dsplit import dsplit
 from .dstack import dstack
 from .equal import equal
+from .expand_dims import expand_dims
 from .floor import floor
 from .floor_divide import floor_divide
 from .hstack import hstack
